@@ -28,7 +28,7 @@ use warnings;
 
 BEGIN
 {
-  our $VERSION = '1.09';
+  our $VERSION = '1.10';
   # This file is part of {{$dist}} {{$dist_version}} ({{$date}})
 
   require Exporter;
@@ -63,9 +63,9 @@ Win32::IPC - Base class for Win32 synchronization objects
 
 =head1 VERSION
 
-This document describes version 1.09 of
-Win32::IPC, released January 14, 2012
-as part of Win32-IPC version 1.09.
+This document describes version 1.10 of
+Win32::IPC, released August 30, 2014
+as part of Win32-IPC version 1.10.
 
 =head1 SYNOPSIS
 
@@ -238,14 +238,14 @@ or through the web interface at
 L<< http://rt.cpan.org/Public/Bug/Report.html?Queue=Win32-IPC >>.
 
 You can follow or contribute to Win32-IPC's development at
-L<< http://github.com/madsen/win32-ipc >>.
+L<< https://github.com/madsen/win32-ipc >>.
 
 Loosely based on the original module by ActiveWare Internet Corp.,
 L<http://www.ActiveState.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 1998-2012 Christopher J. Madsen
+Copyright 1998-2014 Christopher J. Madsen
 
 Created: 3 Feb 1998 from the ActiveWare version
   (c) 1995 Microsoft Corporation. All rights reserved.
